/**
 * Generate a button that will be used for filtering example gallery items.
 *
 * @param {string} id ID of the element to use
 * @param {string} text Text do display to the user inside the button
 * @param {string} icon Icon to show next to the text.
 * @returns {string} Inner HTML that contains the tag filter button.
 */
function generateTagButton(id, text, icon) {
  return `
    <div type='button' id='${id}' class='tag btn btn-outline-primary'>${icon}<span>${text}</span></div>
  `;
}

/**
 * Generate the inner HTML for the tag filter buttons in the sidebar.
 *
 * @param {string} name Name of the section
 * @param {Array<string>} tags Array of tags HTML generated from generateTagButton
 * @returns {string} Inner HTML to display the sidebar
 */
function generateTagSection(name, tags) {
  return `
    <h6>${name}</h6>
    <div class='tag-btn-wrapper'>${tags.join('')}</div>
  `
}

/**
 * Check whether a panel matches the selected filter tags.
 *
 * @param {any} panel Example gallery item
 * @param {Array<Array<string>>} groupedActiveTags Groups of tags selected by the user.
 * @returns {boolean} True if the panel should be shown, false otherwise
 */
function panelMatchesTags(panel, groupedActiveTags) {
  // Show the panel if every tagGroup has at least one active tag in the classList,
  // or if no tag in a group is selected.
  return groupedActiveTags.every(tagGroup => {
    return tagGroup.length === 0 || Array.from(panel.classList).some(tag => tagGroup.includes(tag))
  })
}


/**
 * Filter the links to the examples in the example gallery
 * by the selected tags and the current search query.
 *
 * @param {object} tags Object with grouped arrays of tags, each with className, displayName, and
 * icon
 */
function filterPanels(tags) {
  const noMatchesElement = document.querySelector("#noMatches");
  const query = document.getElementById("searchInput").value.toLowerCase();
  const panels = document.querySelectorAll('.gallery-item')
  const activeTags = Array.from(document.querySelectorAll('.tag.btn-primary')).map(el => el.id);
  const groupedActiveTags = Object.values(tags).map(tagGroup => {
    const classes = tagGroup.map(({className}) => className);
    return activeTags.filter(activeTag => classes.includes(activeTag));
  })

  // Show all panels first
  panels.forEach(panel => panel.classList.remove("hidden"));

  let toHide = [];
  let toShow = [];

  // Show each panel if it has every active tag and matches the search query
  panels.forEach(panel => {
    const text = (panel.textContent + panel.classList.toString()).toLowerCase();
    // const hasTag = activeTags.every(tag => panel.classList.contains(tag));
    const hasTag = panelMatchesTags(panel, groupedActiveTags)
    const hasText = text.includes(query.toLowerCase());

    if (hasTag && hasText) {
      toShow.push(panel);
    } else {
      toHide.push(panel);
    }
  })

  toShow.forEach(panel => panel.classList.remove("hidden"));
  toHide.forEach(panel => panel.classList.add("hidden"));

  // If no matches are found, display the noMatches element
  if (toShow.length === 0) {
      noMatchesElement.classList.remove("hidden");
    } else {
      noMatchesElement.classList.add("hidden");
  }
}

/**
 * Generate the callback triggered when a user clicks on a tag filter button.
 * @param {string} tag The element corresponding to the tag
 * @returns {() => void} The callback that will be called when the user clicks a tag filter button
 */
function generateTagClickHandler(tag, tags) {
  return () => {
    // Toggle "tag" buttons on click.
    if (tag.classList.contains('btn-primary')) {
        // deactivate filter button
        tag.classList.replace('btn-primary', 'btn-outline-primary');
    } else {
        // activate filter button
        tag.classList.replace('btn-outline-primary', 'btn-primary');
    }
    filterPanels(tags)
  }
}

window.addEventListener('load', () => {
    // Sidebar icons
    const rlIcon = `
    <svg width="16" height="8" viewBox="0 0 16 8" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M9.50468 6C8.97443 5.35724 8.67891 4.55304 8.66682 3.71988C8.65473 2.88672 8.92678 2.07428 9.43815 1.4164C9.94952 0.758525 10.6697 0.294442 11.4801 0.1006C12.2905 -0.093242 13.1428 -0.00528085 13.8965 0.349994C14.6502 0.705269 15.2604 1.30667 15.6266 2.05512C15.9929 2.80358 16.0932 3.65445 15.9112 4.46758C15.7292 5.28071 15.2757 6.0076 14.6253 6.52851C13.975 7.04942 13.1666 7.33328 12.3333 7.33334H3.66668C2.83342 7.33328 2.02504 7.04942 1.37469 6.52851C0.724332 6.0076 0.270797 5.28071 0.0887893 4.46758C-0.0932186 3.65445 0.00715685 2.80358 0.373381 2.05512C0.739606 1.30667 1.34984 0.705269 2.10355 0.349994C2.85727 -0.00528085 3.70951 -0.093242 4.5199 0.1006C5.33029 0.294442 6.05049 0.758525 6.56187 1.4164C7.07324 2.07428 7.34529 2.88672 7.3332 3.71988C7.3211 4.55304 7.02559 5.35724 6.49534 6H9.50468V6ZM3.66668 6C4.28551 6 4.87901 5.75417 5.31659 5.31659C5.75418 4.879 6.00001 4.28551 6.00001 3.66667C6.00001 3.04783 5.75418 2.45434 5.31659 2.01675C4.87901 1.57917 4.28551 1.33334 3.66668 1.33334C3.04784 1.33334 2.45434 1.57917 2.01676 2.01675C1.57917 2.45434 1.33334 3.04783 1.33334 3.66667C1.33334 4.28551 1.57917 4.879 2.01676 5.31659C2.45434 5.75417 3.04784 6 3.66668 6V6ZM12.3333 6C12.9522 6 13.5457 5.75417 13.9833 5.31659C14.4208 4.879 14.6667 4.28551 14.6667 3.66667C14.6667 3.04783 14.4208 2.45434 13.9833 2.01675C13.5457 1.57917 12.9522 1.33334 12.3333 1.33334C11.7145 1.33334 11.121 1.57917 10.6834 2.01675C10.2458 2.45434 10 3.04783 10 3.66667C10 4.28551 10.2458 4.879 10.6834 5.31659C11.121 5.75417 11.7145 6 12.3333 6V6Z" fill="black"/>
    </svg>
    `;
    const otherIcon = `
    <svg width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M10.3333 2H13C13.1768 2 13.3464 2.07024 13.4714 2.19526C13.5964 2.32029 13.6666 2.48986 13.6666 2.66667V13.3333C13.6666 13.5101 13.5964 13.6797 13.4714 13.8047C13.3464 13.9298 13.1768 14 13 14H0.99998C0.823169 14 0.653599 13.9298 0.528575 13.8047C0.403551 13.6797 0.333313 13.5101 0.333313 13.3333V2.66667C0.333313 2.48986 0.403551 2.32029 0.528575 2.19526C0.653599 2.07024 0.823169 2 0.99998 2H3.66665V0.666668H4.99998V2H8.99998V0.666668H10.3333V2ZM8.99998 3.33333H4.99998V4.66667H3.66665V3.33333H1.66665V6H12.3333V3.33333H10.3333V4.66667H8.99998V3.33333ZM12.3333 7.33333H1.66665V12.6667H12.3333V7.33333Z" fill="black"/>
    </svg>
    `;
    const llmIcon = `
    <svg width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M11.6666 13.6667H2.33331C1.80288 13.6667 1.29417 13.456 0.9191 13.0809C0.544027 12.7058 0.333313 12.1971 0.333313 11.6667V1.00001C0.333313 0.823199 0.403551 0.65363 0.528575 0.528606C0.653599 0.403581 0.823169 0.333344 0.99998 0.333344H10.3333C10.5101 0.333344 10.6797 0.403581 10.8047 0.528606C10.9297 0.65363 11 0.823199 11 1.00001V9.00001H13.6666V11.6667C13.6666 12.1971 13.4559 12.7058 13.0809 13.0809C12.7058 13.456 12.1971 13.6667 11.6666 13.6667ZM11 10.3333V11.6667C11 11.8435 11.0702 12.0131 11.1952 12.1381C11.3203 12.2631 11.4898 12.3333 11.6666 12.3333C11.8435 12.3333 12.013 12.2631 12.1381 12.1381C12.2631 12.0131 12.3333 11.8435 12.3333 11.6667V10.3333H11ZM9.66665 12.3333V1.66668H1.66665V11.6667C1.66665 11.8435 1.73688 12.0131 1.86191 12.1381C1.98693 12.2631 2.1565 12.3333 2.33331 12.3333H9.66665ZM2.99998 3.66668H8.33331V5.00001H2.99998V3.66668ZM2.99998 6.33334H8.33331V7.66668H2.99998V6.33334ZM2.99998 9.00001H6.33331V10.3333H2.99998V9.00001Z" fill="black"/>
    </svg>
    `;
    const nlpIcon = `
    <svg width="12" height="13" viewBox="0 0 12 13" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M8.164 7.33333H3.836L2.76933 10H1.33333L5.33333 0H6.66667L10.6667 10H9.23067L8.164 7.33333ZM7.63067 6L6 1.92333L4.36933 6H7.63067V6ZM0 11.3333H12V12.6667H0V11.3333Z" fill="black"/>
    </svg>
    `;
    const timeSeriesIcon = `
    <svg width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M6.99998 0.333344C10.68 0.333344 13.6666 3.32001 13.6666 7.00001C13.6666 10.68 10.68 13.6667 6.99998 13.6667C3.31998 13.6667 0.333313 10.68 0.333313 7.00001C0.333313 3.32001 3.31998 0.333344 6.99998 0.333344ZM6.99998 12.3333C9.94665 12.3333 12.3333 9.94668 12.3333 7.00001C12.3333 4.05334 9.94665 1.66668 6.99998 1.66668C4.05331 1.66668 1.66665 4.05334 1.66665 7.00001C1.66665 9.94668 4.05331 12.3333 6.99998 12.3333ZM9.35731 3.70001L10.3 4.64268L6.99998 7.94268L6.05731 7.00001L9.35731 3.70001V3.70001Z" fill="black"/>
    </svg>
    `;
    const computerVisionIcon = `
    <svg width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M6.99998 0.333344C10.682 0.333344 13.6666 3.31801 13.6666 7.00001C13.6666 10.682 10.682 13.6667 6.99998 13.6667C3.31798 13.6667 0.333313 10.682 0.333313 7.00001C0.333313 3.31801 3.31798 0.333344 6.99998 0.333344ZM6.99998 1.66668C5.58549 1.66668 4.22894 2.22858 3.22874 3.22877C2.22855 4.22897 1.66665 5.58552 1.66665 7.00001C1.66665 8.4145 2.22855 9.77105 3.22874 10.7712C4.22894 11.7714 5.58549 12.3333 6.99998 12.3333C8.41447 12.3333 9.77102 11.7714 10.7712 10.7712C11.7714 9.77105 12.3333 8.4145 12.3333 7.00001C12.3333 5.58552 11.7714 4.22897 10.7712 3.22877C9.77102 2.22858 8.41447 1.66668 6.99998 1.66668V1.66668ZM6.99998 3.66668C7.7017 3.66694 8.38545 3.88866 8.95379 4.30024C9.52214 4.71181 9.94611 5.29226 10.1653 5.95888C10.3845 6.62549 10.3877 7.34428 10.1745 8.01283C9.96124 8.68137 9.54248 9.26558 8.97783 9.68222C8.41317 10.0989 7.73144 10.3267 7.02975 10.3332C6.32805 10.3397 5.64219 10.1247 5.06988 9.7186C4.49758 9.31255 4.06801 8.73624 3.84238 8.07177C3.61676 7.40731 3.60659 6.68859 3.81331 6.01801C3.96926 6.36649 4.24016 6.65083 4.58068 6.82345C4.92121 6.99608 5.31069 7.04651 5.68394 6.96632C6.0572 6.88612 6.3916 6.68016 6.63116 6.3829C6.87073 6.08564 7.00093 5.71512 6.99998 5.33334C7.00007 5.01232 6.90744 4.6981 6.73324 4.42846C6.55903 4.15882 6.31066 3.94522 6.01798 3.81334C6.32865 3.71801 6.65798 3.66668 6.99998 3.66668V3.66668Z" fill="black"/>
    </svg>
    `
    const batchInferenceIcon = `
    <svg width="14" height="13" viewBox="0 0 14 13" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M4.7779 5.67397C4.66518 5.67477 4.55342 5.65315 4.44913 5.61038C4.34483 5.56761 4.25008 5.50454 4.17037 5.42483C4.09066 5.34513 4.02759 5.25037 3.98482 5.14608C3.94205 5.04178 3.92044 4.93002 3.92124 4.8173C3.92124 4.33863 4.29924 3.95997 4.7779 3.95997C5.2559 3.95997 5.63457 4.33863 5.63457 4.8173C5.63457 5.2953 5.2559 5.67397 4.7779 5.67397ZM9.2219 5.67397C9.10918 5.67477 8.99743 5.65315 8.89313 5.61038C8.78883 5.56761 8.69408 5.50454 8.61437 5.42483C8.53466 5.34513 8.47159 5.25037 8.42882 5.14608C8.38605 5.04178 8.36444 4.93002 8.36524 4.8173C8.36524 4.33863 8.7439 3.95997 9.2219 3.95997C9.70057 3.95997 10.0786 4.33863 10.0786 4.8173C10.0786 5.2953 9.70057 5.67397 9.2219 5.67397ZM3.54857 10.81L4.02524 10.5193C4.56499 10.1902 5.2041 10.0636 5.82857 10.162C5.9699 10.184 6.0859 10.2013 6.17524 10.2126C6.4459 10.2486 6.7219 10.2666 6.9999 10.2666C9.94657 10.2666 12.2666 8.25197 12.2666 5.86663C12.2666 3.4813 9.94657 1.46663 6.9999 1.46663C4.05324 1.46663 1.73324 3.4813 1.73324 5.86663C1.73324 6.7773 2.06657 7.64863 2.6879 8.3873C2.7199 8.4253 2.7679 8.47863 2.83057 8.54397C3.09262 8.81687 3.29359 9.14242 3.42015 9.49897C3.5467 9.85552 3.59593 10.2349 3.56457 10.612L3.5479 10.81H3.54857ZM3.12857 12.628C3.02371 12.6936 2.90267 12.7287 2.77898 12.7295C2.6553 12.7302 2.53384 12.6965 2.4282 12.6322C2.32257 12.5678 2.23691 12.4754 2.18081 12.3651C2.12472 12.2549 2.1004 12.1312 2.11057 12.008L2.2359 10.5013C2.25163 10.3128 2.22706 10.1231 2.16384 9.94484C2.10063 9.76657 2.0002 9.60378 1.86924 9.4673C1.79931 9.3955 1.73172 9.32146 1.66657 9.2453C0.870569 8.29797 0.399902 7.12997 0.399902 5.86663C0.399902 2.69997 3.35457 0.133301 6.9999 0.133301C10.6452 0.133301 13.5999 2.69997 13.5999 5.86663C13.5999 9.0333 10.6452 11.6 6.9999 11.6C6.6599 11.6 6.32657 11.578 6.00057 11.5346C5.8739 11.5175 5.74745 11.4988 5.62124 11.4786C5.3089 11.4293 4.98921 11.4927 4.71924 11.6573L3.1279 12.628H3.12857Z" fill="black"/>
    </svg>
    `
    const dataPreprocessingIcon = `
    <svg width="14" height="12" viewBox="0 0 14 12" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M6.33325 10.6667V4H1.66659V10.6667H6.33325ZM6.33325 2.66667V0.666667C6.33325 0.489856 6.40349 0.320286 6.52851 0.195262C6.65354 0.0702379 6.82311 0 6.99992 0H12.9999C13.1767 0 13.3463 0.0702379 13.4713 0.195262C13.5963 0.320286 13.6666 0.489856 13.6666 0.666667V11.3333C13.6666 11.5101 13.5963 11.6797 13.4713 11.8047C13.3463 11.9298 13.1767 12 12.9999 12H0.999919C0.823108 12 0.653538 11.9298 0.528514 11.8047C0.40349 11.6797 0.333252 11.5101 0.333252 11.3333V3.33333C0.333252 3.15652 0.40349 2.98695 0.528514 2.86193C0.653538 2.7369 0.823108 2.66667 0.999919 2.66667H6.33325ZM7.66659 1.33333V10.6667H12.3333V1.33333H7.66659ZM2.33325 8.66667H5.66659V10H2.33325V8.66667ZM8.33325 8.66667H11.6666V10H8.33325V8.66667ZM8.33325 6.66667H11.6666V8H8.33325V6.66667ZM8.33325 4.66667H11.6666V6H8.33325V4.66667ZM2.33325 6.66667H5.66659V8H2.33325V6.66667Z" fill="black"/>
    </svg>
    `
    const dataValidationIcon = `
    <svg width="16" height="9" viewBox="0 0 16 9" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M7.73475 6.1733L8.67608 7.11463L14.3201 1.47063L15.2627 2.4133L8.67608 8.99996L4.43341 4.7573L5.37608 3.81463L6.79275 5.2313L7.73475 6.17263V6.1733ZM7.73608 4.28796L11.0374 0.985962L11.9774 1.92596L8.67608 5.22796L7.73608 4.28796ZM5.85141 8.05796L4.90941 8.99996L0.666748 4.7573L1.60941 3.81463L2.55141 4.75663L2.55075 4.7573L5.85141 8.05796Z" fill="black"/>
    </svg>
    `
    const experimentTrackingIcon = `
    <svg width="13" height="12" viewBox="0 0 13 12" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M10.9999 0C12.1046 0 12.9999 0.895333 12.9999 2C12.9999 3.10467 12.1046 4 10.9999 4H8.99992C8.12925 4 7.38859 3.444 7.11392 2.66667H6.33325C5.59992 2.66667 4.99992 3.26667 4.99992 4V4.114C5.77725 4.38867 6.33325 5.12933 6.33325 6C6.33325 6.87067 5.77725 7.61133 4.99992 7.886V8C4.99992 8.73333 5.59992 9.33333 6.33325 9.33333H7.11325C7.38792 8.55667 8.12925 8 8.99992 8H10.9999C12.1046 8 12.9999 8.89533 12.9999 10C12.9999 11.1047 12.1046 12 10.9999 12H8.99992C8.12925 12 7.38859 11.444 7.11392 10.6667H6.33325C4.85992 10.6667 3.66659 9.47333 3.66659 8H2.33325C1.22859 8 0.333252 7.10467 0.333252 6C0.333252 4.89533 1.22859 4 2.33325 4H3.66659C3.66659 2.52667 4.85992 1.33333 6.33325 1.33333H7.11325C7.38792 0.556667 8.12925 0 8.99992 0H10.9999ZM10.9999 9.33333H8.99992C8.63192 9.33333 8.33325 9.632 8.33325 10C8.33325 10.368 8.63192 10.6667 8.99992 10.6667H10.9999C11.3679 10.6667 11.6666 10.368 11.6666 10C11.6666 9.632 11.3679 9.33333 10.9999 9.33333ZM4.33325 5.33333H2.33325C1.96525 5.33333 1.66659 5.632 1.66659 6C1.66659 6.368 1.96525 6.66667 2.33325 6.66667H4.33325C4.70125 6.66667 4.99992 6.368 4.99992 6C4.99992 5.632 4.70125 5.33333 4.33325 5.33333ZM10.9999 1.33333H8.99992C8.63192 1.33333 8.33325 1.632 8.33325 2C8.33325 2.368 8.63192 2.66667 8.99992 2.66667H10.9999C11.3679 2.66667 11.6666 2.368 11.6666 2C11.6666 1.632 11.3679 1.33333 10.9999 1.33333Z" fill="black"/>
    </svg>
    `
    const hyperparameterTuningIcon = `
    <svg width="16" height="16" viewBox="0 0 16 16" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M8.66675 0.666626L8.66741 2.70796C9.84222 2.85649 10.9343 3.39158 11.7715 4.22897C12.6088 5.06636 13.1437 6.15846 13.2921 7.33329H15.3334V8.66663L13.2921 8.66729C13.1436 9.842 12.6086 10.934 11.7713 11.7712C10.9341 12.6085 9.84212 13.1435 8.66741 13.292L8.66675 15.3333H7.33341V13.292C6.15858 13.1436 5.06648 12.6087 4.22909 11.7714C3.3917 10.9341 2.85661 9.8421 2.70808 8.66729L0.666748 8.66663V7.33329H2.70808C2.85647 6.15836 3.3915 5.06618 4.2289 4.22878C5.0663 3.39138 6.15849 2.85635 7.33341 2.70796V0.666626H8.66675ZM8.00008 3.99996C6.93922 3.99996 5.9218 4.42139 5.17165 5.17153C4.42151 5.92168 4.00008 6.93909 4.00008 7.99996C4.00008 9.06082 4.42151 10.0782 5.17165 10.8284C5.9218 11.5785 6.93922 12 8.00008 12C9.06095 12 10.0784 11.5785 10.8285 10.8284C11.5787 10.0782 12.0001 9.06082 12.0001 7.99996C12.0001 6.93909 11.5787 5.92168 10.8285 5.17153C10.0784 4.42139 9.06095 3.99996 8.00008 3.99996ZM8.00008 6.66663C8.3537 6.66663 8.69284 6.8071 8.94289 7.05715C9.19294 7.3072 9.33341 7.64634 9.33341 7.99996C9.33341 8.35358 9.19294 8.69272 8.94289 8.94277C8.69284 9.19282 8.3537 9.33329 8.00008 9.33329C7.64646 9.33329 7.30732 9.19282 7.05727 8.94277C6.80722 8.69272 6.66675 8.35358 6.66675 7.99996C6.66675 7.64634 6.80722 7.3072 7.05727 7.05715C7.30732 6.8071 7.64646 6.66663 8.00008 6.66663Z" fill="black"/>
    </svg>
    `
    const modelTrainingIcon = `
    <svg width="13" height="12" viewBox="0 0 13 12" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M1.33333 0V10.6667H12V12H0V0H1.33333ZM11.5287 2.19533L12.4713 3.138L8.66667 6.94267L6.66667 4.94333L3.80467 7.80467L2.862 6.862L6.66667 3.05733L8.66667 5.05667L11.5287 2.19533Z" fill="black"/>
    </svg>
    `
    const monitoringIcon = `
    <svg width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M6.99992 0.333374C10.6819 0.333374 13.6666 3.31804 13.6666 7.00004C13.6666 10.682 10.6819 13.6667 6.99992 13.6667C3.31792 13.6667 0.333252 10.682 0.333252 7.00004C0.333252 3.31804 3.31792 0.333374 6.99992 0.333374ZM6.99992 1.66671C4.05459 1.66671 1.66659 4.05471 1.66659 7.00004C1.66659 9.94537 4.05459 12.3334 6.99992 12.3334C9.94525 12.3334 12.3333 9.94537 12.3333 7.00004C12.3333 4.05471 9.94525 1.66671 6.99992 1.66671ZM6.99992 2.33337C7.67859 2.33337 8.32325 2.47804 8.90525 2.73871L7.86325 3.78004C7.58792 3.70671 7.29859 3.66671 6.99992 3.66671C5.15925 3.66671 3.66659 5.15937 3.66659 7.00004C3.66659 7.92004 4.03992 8.75337 4.64259 9.35737L3.69992 10.3L3.59592 10.1927C2.81325 9.35804 2.33325 8.23471 2.33325 7.00004C2.33325 4.42271 4.42259 2.33337 6.99992 2.33337ZM11.2613 5.09537C11.5213 5.67671 11.6666 6.32204 11.6666 7.00004C11.6666 8.28871 11.1439 9.45537 10.2999 10.3L9.35725 9.35737C9.95992 8.75337 10.3333 7.92004 10.3333 7.00004C10.3333 6.70137 10.2939 6.41204 10.2199 6.13671L11.2613 5.09537ZM9.82792 3.22871L10.7713 4.17137L8.28859 6.65537C8.31792 6.76537 8.33325 6.88071 8.33325 7.00004C8.33325 7.73671 7.73659 8.33337 6.99992 8.33337C6.26325 8.33337 5.66659 7.73671 5.66659 7.00004C5.66659 6.26337 6.26325 5.66671 6.99992 5.66671C7.11925 5.66671 7.23459 5.68204 7.34459 5.71137L9.82859 3.22871H9.82792Z" fill="black"/>
    </svg>
    `
    const orchestrationIcon = `
    <svg width="14" height="14" viewBox="0 0 14 14" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M7.33735 1.41534L6.65535 2.59667C4.71535 2.01067 2.97935 2.29667 2.38135 3.33334C1.59602 4.69334 2.90802 7.10134 5.50002 8.59801C8.09202 10.0947 10.8333 10.026 11.6187 8.66667C12.2173 7.63001 11.5967 5.98401 10.1193 4.59667L10.8013 3.41534C12.856 5.22134 13.7767 7.59534 12.7733 9.33334C11.5333 11.4813 7.98068 11.57 4.83335 9.75334C1.68602 7.93467 -0.0133173 4.81401 1.22668 2.66667C2.23002 0.928673 4.74668 0.538673 7.33735 1.41534ZM9.58935 0.182007L10.744 0.848674L7.41068 6.62201L6.25602 5.95534L9.58935 0.182007ZM3.48802 12.3333H10.3333V13.6667H2.34468C2.22568 13.669 2.10824 13.6393 2.00466 13.5807C1.90109 13.522 1.81521 13.4366 1.75602 13.3333C1.69783 13.2319 1.66721 13.117 1.66721 13C1.66721 12.883 1.69783 12.7681 1.75602 12.6667L3.25602 10.0687L4.41068 10.7353L3.48802 12.3333Z" fill="black"/>
    </svg>
    `
    const servingIcon = `
    <svg width="16" height="14" viewBox="0 0 16 14" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M9.33342 11V9.66665H11.6667C12.0514 9.66659 12.4302 9.57143 12.7692 9.38962C13.1082 9.20781 13.397 8.945 13.6099 8.62458C13.8228 8.30417 13.9531 7.93609 13.9894 7.5531C14.0256 7.17012 13.9666 6.78412 13.8176 6.42946C13.6686 6.07481 13.4342 5.76249 13.1353 5.52033C12.8364 5.27816 12.4822 5.11365 12.1044 5.04145C11.7265 4.96925 11.3367 4.99158 10.9695 5.10648C10.6024 5.22137 10.2694 5.42526 10.0001 5.69998V5.66665C10.0001 4.60578 9.57866 3.58837 8.82851 2.83822C8.07836 2.08808 7.06095 1.66665 6.00008 1.66665C4.93922 1.66665 3.9218 2.08808 3.17166 2.83822C2.42151 3.58837 2.00008 4.60578 2.00008 5.66665V5.67131H0.66675V5.66665C0.66574 4.42208 1.10002 3.21636 1.89437 2.25827C2.68873 1.30018 3.79314 0.650058 5.01635 0.420499C6.23956 0.190939 7.50454 0.396394 8.59222 1.00128C9.6799 1.60617 10.5218 2.5724 10.9721 3.73265C11.4736 3.63618 11.9898 3.64556 12.4876 3.76018C12.9853 3.87481 13.4536 4.09216 13.8624 4.3983C14.2712 4.70445 14.6116 5.09263 14.8617 5.53796C15.1118 5.9833 15.2661 6.47598 15.3147 6.98442C15.3633 7.49286 15.3051 8.00584 15.1439 8.49049C14.9827 8.97514 14.7221 9.42077 14.3786 9.79882C14.0352 10.1769 13.6166 10.479 13.1496 10.6858C12.6826 10.8927 12.1775 10.9997 11.6667 11H9.33342ZM4.00008 12.3333H10.6667V13.6666H4.00008V12.3333ZM4.00008 6.99998H9.33342V8.33331H4.00008V6.99998ZM1.33342 9.66665H8.00008V11H1.33342V9.66665Z" fill="black"/>
    </svg>
    `
    const tensorflowIcon = `
    <svg xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:cc="http://creativecommons.org/ns#" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:svg="http://www.w3.org/2000/svg" xmlns="http://www.w3.org/2000/svg" width="15" height="16" id="svg8" version="1.1" viewBox="0 0 30.31081 32.499828" height="122.83399" width="114.56054">
      <defs id="defs2"/>
      <metadata id="metadata5">
        <rdf:RDF>
          <cc:Work rdf:about="">
            <dc:format>image/svg+xml</dc:format>
            <dc:type rdf:resource="http://purl.org/dc/dcmitype/StillImage"/>
            <dc:title/>
          </cc:Work>
        </rdf:RDF>
      </metadata>
      <g transform="translate(-77.942529,-177.00005)" id="layer1">
        <g id="g4550">
          <path style="fill:#e55b2d;fill-opacity:1" d="m 360.04883,687.87305 v 18.89843 l 32.73047,18.89844 v -18.89844 z m -65.46289,18.89843 v 18.89844 l 16.36523,9.44727 V 716.2207 Z m 49.0957,9.44922 -16.36523,9.44922 v 56.69141 l 16.36523,9.44922 v -37.79493 l 16.36719,9.44922 v -18.89843 l -16.36719,-9.44922 z" transform="scale(0.26458333)" id="path4508"/>
          <path style="fill:#ed8e24;fill-opacity:1" d="m 360.04883,687.87305 -49.09766,28.34765 v 18.89649 l 32.73047,-18.89649 v 18.89649 l 16.36719,-9.44727 z m 49.09765,9.44922 -16.36718,9.44921 v 18.89844 l 16.36718,-9.44922 z m -32.73242,37.79492 -16.36523,9.44922 v 18.89843 l 16.36523,-9.44922 z m -16.36523,28.34765 -16.36719,-9.44922 v 37.79493 l 16.36719,-9.44922 z" transform="scale(0.26458333)" id="path4491"/>
          <path style="fill:#f8bf3c;fill-opacity:1" d="m 360.04883,668.97656 -65.46289,37.79492 16.36523,9.44922 49.09766,-28.34765 32.73047,18.89843 16.36718,-9.44921 z m 0,56.69336 -16.36719,9.44727 16.36719,9.44922 16.36523,-9.44922 z" transform="scale(0.26458333)" id="path4506"/>
        </g>
      </g>
    </svg>
    `
    const pytorchIcon = `
    <svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="13" height="16" viewBox="0.6 1067.9 90.3 109.1" enable-background="new 0.6 1067.9 90.3 109.1" xml:space="preserve">
      <g>
        <path fill="#EE4C2C" d="M77.6,1099.6l-8.1,8.1c13.3,13.3,13.3,34.7,0,47.8c-13.3,13.3-34.7,13.3-47.8,0   c-13.3-13.3-13.3-34.7,0-47.8l0,0l21.1-21.1l3-3l0,0v-15.9l-31.8,31.8c-17.7,17.7-17.7,46.3,0,64c17.7,17.7,46.3,17.7,63.7,0   C95.3,1145.8,95.3,1117.4,77.6,1099.6z"/>
        <circle fill="#EE4C2C" cx="61.7" cy="1091.8" r="5.9"/>
      </g>
    </svg>
    `
    const kerasIcon = `
    <svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="14" height="14" viewBox="0 0 1080 1080" style="enable-background:new 0 0 1080 1080;" xml:space="preserve">
      <style type="text/css">
        .st0{fill:#FFFFFF;}
        .st1{fill:#D00000;}
      </style>
      <g>
        <path class="st0" d="M1080,1079.96c0,0.02-0.02,0.04-0.04,0.04H0.04c-0.02,0-0.04-0.02-0.04-0.04V0.04C0,0.02,0.02,0,0.04,0   h1079.93c0.02,0,0.04,0.02,0.04,0.04V1079.96z"/>
      </g>
      <g>
        <path class="st1" d="M1062,1061.96c0,0.02-0.02,0.04-0.04,0.04H18.04c-0.02,0-0.04-0.02-0.04-0.04V18.04   c0-0.02,0.02-0.04,0.04-0.04h1043.93c0.02,0,0.04,0.02,0.04,0.04V1061.96z"/>
      </g>
      <g>
        <path class="st0" d="M303,823.67c0,0.79,0.46,1.89,1.01,2.44l17.87,17.87c0.56,0.56,1.66,1.01,2.44,1.01h61.15   c0.79,0,1.89-0.46,2.44-1.01l17.87-17.87c0.56-0.56,1.01-1.66,1.01-2.44V629.64c0-0.79,0.47-1.88,1.04-2.42l77.69-74.2   c0.57-0.54,1.4-0.46,1.84,0.2l196.29,290.6c0.44,0.65,1.45,1.19,2.23,1.19h86.63c0.79,0,1.73-0.57,2.09-1.27l15.72-30.46   c0.36-0.7,0.29-1.8-0.16-2.45L560.56,478.03c-0.45-0.65-0.36-1.63,0.2-2.19l211.18-210.19c0.56-0.56,1.01-1.65,1.01-2.44v-3.88   c0-0.79-0.26-2.02-0.57-2.75l-12.18-28.01c-0.31-0.72-1.22-1.31-2-1.31h-85.63c-0.79,0-1.89,0.46-2.44,1.01l-262.31,263.3   c-0.56,0.56-1.01,0.37-1.01-0.42V249.6c0-0.79-0.44-1.9-0.98-2.48l-17.53-18.8c-0.54-0.58-1.62-1.05-2.41-1.05h-61.57   c-0.79,0-1.87,0.47-2.41,1.05l-17.95,19.38c-0.54,0.58-0.97,1.69-0.97,2.48V823.67z"/>
      </g>
    </svg>
    `
    const huggingfaceIcon = `
    <svg width="19" height="19" viewBox="0 0 256 256" fill="none" xmlns="http://www.w3.org/2000/svg">
      <path d="M230.721 172.7C230.183 170.673 229.313 168.75 228.146 167.008C228.396 166.091 228.587 165.159 228.714 164.217C229.543 158.241 227.471 152.77 223.567 148.537C221.452 146.225 219.185 144.698 216.784 143.761C218.36 137.018 219.157 130.117 219.161 123.193C219.161 120.03 218.982 116.932 218.682 113.88C218.526 112.356 218.337 110.836 218.115 109.32C217.428 104.847 216.408 100.431 215.064 96.11C214.183 93.2707 213.164 90.476 212.01 87.736C210.281 83.6782 208.262 79.75 205.969 75.982C204.465 73.475 202.827 71.0508 201.062 68.72C200.197 67.543 199.296 66.3938 198.358 65.274C195.58 61.898 192.561 58.7277 189.325 55.788C188.25 54.7997 187.145 53.8453 186.01 52.926C184.893 51.9943 183.751 51.0927 182.586 50.222C180.241 48.4766 177.818 46.8392 175.324 45.315C161.543 36.945 145.382 32.145 128.109 32.145C77.817 32.145 37.057 72.907 37.057 123.196C37.055 130.208 37.867 137.196 39.477 144.02C37.317 144.958 35.247 146.42 33.327 148.535C29.424 152.766 27.351 158.217 28.18 164.193C28.306 165.142 28.495 166.082 28.747 167.006C27.5811 168.749 26.7117 170.673 26.174 172.7C24.974 177.261 25.369 181.374 26.894 184.978C25.236 189.688 25.65 194.704 27.809 199.065C29.379 202.25 31.626 204.714 34.396 206.916C37.689 209.534 41.811 211.758 46.783 213.892C52.715 216.422 59.956 218.799 63.249 219.671C71.755 221.873 79.911 223.269 88.177 223.337C99.954 223.446 110.096 220.677 117.357 213.59C120.924 214.027 124.515 214.246 128.109 214.244C131.906 214.236 135.699 213.997 139.467 213.529C146.711 220.661 156.892 223.455 168.712 223.343C176.977 223.277 185.133 221.881 193.617 219.676C196.932 218.804 204.17 216.427 210.105 213.897C215.077 211.76 219.199 209.536 222.514 206.922C225.263 204.719 227.508 202.256 229.079 199.071C231.26 194.709 231.652 189.693 230.017 184.983C231.527 181.379 231.92 177.257 230.721 172.7ZM222.281 184.673C223.952 187.844 224.059 191.427 222.585 194.764C220.349 199.821 214.795 203.805 204.008 208.082C197.3 210.742 191.158 212.443 191.104 212.458C182.232 214.759 174.208 215.928 167.262 215.928C155.76 215.928 147.201 212.754 141.773 206.486C132.594 208.05 123.222 208.103 114.026 206.644C108.591 212.808 100.081 215.928 88.676 215.928C81.729 215.928 73.706 214.759 64.833 212.458C64.779 212.443 58.639 210.742 51.929 208.082C41.143 203.805 35.587 199.824 33.352 194.764C31.878 191.427 31.985 187.844 33.656 184.673C33.81 184.378 33.976 184.091 34.153 183.813C33.1516 182.309 32.4799 180.61 32.182 178.827C31.8842 177.045 31.967 175.22 32.425 173.472C33.089 170.949 34.46 168.851 36.322 167.344C35.425 165.87 34.8365 164.23 34.592 162.522C34.056 158.808 35.289 155.1 38.062 152.076C40.222 149.723 43.275 148.428 46.655 148.428H46.745C44.1965 140.259 42.9044 131.75 42.913 123.193C42.913 76.522 80.749 38.683 127.427 38.683C174.104 38.683 211.94 76.518 211.94 123.193C211.947 131.773 210.646 140.304 208.081 148.492C208.489 148.452 208.889 148.432 209.282 148.431C212.662 148.431 215.716 149.726 217.874 152.079C220.647 155.1 221.881 158.811 221.344 162.525C221.1 164.233 220.511 165.873 219.615 167.347C221.477 168.854 222.849 170.952 223.512 173.475C223.97 175.223 224.053 177.048 223.755 178.831C223.458 180.613 222.786 182.312 221.784 183.816C221.961 184.091 222.129 184.378 222.281 184.673Z" fill="white"/>
      <path d="M221.784 183.816C222.786 182.312 223.458 180.613 223.756 178.831C224.053 177.048 223.97 175.223 223.512 173.475C222.848 170.952 221.476 168.854 219.615 167.347C220.512 165.873 221.1 164.233 221.344 162.525C221.881 158.811 220.648 155.103 217.874 152.079C215.716 149.726 212.662 148.431 209.282 148.431C208.889 148.431 208.489 148.452 208.081 148.492C210.643 140.304 211.942 131.774 211.933 123.195C211.933 76.5231 174.097 38.6851 127.424 38.6851C80.75 38.6851 42.9099 76.5191 42.9099 123.195C42.9015 131.752 44.1936 140.261 46.742 148.43H46.6519C43.2719 148.43 40.219 149.724 38.06 152.077C35.287 155.098 34.0529 158.81 34.5899 162.523C34.8346 164.231 35.4231 165.872 36.3199 167.346C34.4579 168.852 33.086 170.95 32.422 173.473C31.9642 175.222 31.8817 177.047 32.1799 178.83C32.4781 180.612 33.1501 182.312 34.1519 183.816C33.9739 184.094 33.8099 184.381 33.6549 184.676C31.9849 187.847 31.877 191.43 33.352 194.767C35.588 199.824 41.1419 203.808 51.9289 208.085C58.6359 210.745 64.779 212.446 64.833 212.461C73.705 214.762 81.729 215.931 88.675 215.931C100.081 215.931 108.591 212.811 114.026 206.647C123.222 208.106 132.594 208.052 141.773 206.489C147.201 212.757 155.76 215.931 167.262 215.931C174.208 215.931 182.232 214.762 191.103 212.461C191.158 212.446 197.298 210.745 204.008 208.085C214.795 203.808 220.35 199.824 222.585 194.767C224.059 191.43 223.952 187.847 222.281 184.676C222.129 184.379 221.961 184.091 221.784 183.816ZM110.137 196.997C109.669 197.815 109.168 198.614 108.635 199.391C107.23 201.448 105.382 203.02 103.237 204.188C99.1369 206.424 93.947 207.205 88.675 207.205C80.346 207.205 71.808 205.256 67.023 204.015C66.787 203.954 37.689 195.735 41.373 188.739C41.993 187.562 43.0129 187.092 44.2979 187.092C49.4849 187.092 58.9299 194.816 62.9889 194.816C63.8959 194.816 64.5359 194.43 64.7969 193.488C66.5269 187.284 38.5039 184.676 40.8639 175.692C41.2799 174.102 42.41 173.456 43.998 173.456C50.856 173.455 66.248 185.516 69.467 185.516C69.714 185.516 69.8909 185.443 69.9869 185.291C70.0009 185.268 70.015 185.246 70.028 185.222C71.539 182.727 70.6719 180.913 60.3209 174.573L59.3269 173.968C47.9359 167.074 39.9409 162.925 44.4879 157.975C45.0109 157.404 45.7529 157.151 46.6539 157.151C47.7219 157.151 49.0149 157.508 50.4389 158.108C56.4549 160.645 64.793 167.564 68.276 170.581C68.8239 171.057 69.3683 171.538 69.9089 172.022C69.9089 172.022 74.319 176.608 76.985 176.608C77.599 176.608 78.1199 176.366 78.4729 175.768C80.364 172.58 60.9099 157.838 59.8129 151.755C59.0689 147.634 60.3349 145.546 62.6749 145.546C63.7879 145.546 65.1459 146.02 66.6449 146.971C71.2949 149.922 80.2729 165.35 83.5599 171.352C84.6619 173.363 86.5429 174.213 88.2379 174.213C91.6009 174.213 94.2299 170.87 88.5459 166.622C80.0029 160.23 83.001 149.782 87.078 149.139C87.252 149.111 87.4279 149.097 87.6029 149.097C91.3109 149.097 92.9459 155.486 92.9459 155.486C92.9459 155.486 97.7399 167.524 105.975 175.753C113.447 183.222 114.491 189.351 110.137 196.997ZM136.766 198.407L136.339 198.458L135.611 198.541C135.228 198.581 134.844 198.619 134.459 198.654L134.084 198.688L133.741 198.717L133.255 198.756L132.718 198.795L132.182 198.83L132.063 198.838C131.923 198.846 131.783 198.855 131.641 198.862L131.462 198.872C131.296 198.881 131.13 198.889 130.962 198.896L130.381 198.921L129.854 198.939L129.502 198.949H129.323C129.213 198.949 129.104 198.955 128.994 198.956H128.82C128.71 198.956 128.601 198.956 128.491 198.961L128.043 198.967H127.418C126.927 198.967 126.437 198.962 125.949 198.952L125.553 198.943C125.44 198.943 125.327 198.938 125.216 198.934L124.796 198.922L124.275 198.902L123.805 198.881L123.684 198.876L123.237 198.853C123.112 198.846 122.989 198.84 122.865 198.831L122.576 198.814C122.213 198.791 121.85 198.766 121.487 198.738L121.107 198.707C120.947 198.695 120.787 198.68 120.628 198.666C120.441 198.65 120.254 198.632 120.067 198.614C119.754 198.585 119.441 198.553 119.128 198.519H119.113C123.683 188.324 121.372 178.802 112.137 169.575C106.08 163.526 102.051 154.594 101.215 152.633C99.5229 146.828 95.045 140.375 87.608 140.375C86.979 140.375 86.351 140.425 85.73 140.523C82.472 141.036 79.624 142.911 77.592 145.733C75.396 143.002 73.262 140.831 71.332 139.605C68.422 137.76 65.5179 136.824 62.6889 136.824C59.1579 136.824 56.0019 138.274 53.8019 140.904L53.7459 140.971C53.7039 140.798 53.6639 140.625 53.6229 140.451L53.6179 140.428C53.1992 138.638 52.8477 136.833 52.5639 135.016C52.5639 135.004 52.5639 134.992 52.5579 134.98C52.5359 134.843 52.5159 134.705 52.4949 134.568C52.4334 134.162 52.3757 133.755 52.3219 133.348C52.2979 133.163 52.2719 132.978 52.2489 132.793L52.1809 132.238C52.1589 132.053 52.1409 131.885 52.1209 131.709L52.115 131.665C52.0351 130.945 51.9651 130.225 51.9049 129.503L51.8829 129.226L51.8479 128.754C51.8379 128.625 51.8279 128.495 51.8209 128.365C51.8209 128.334 51.8159 128.304 51.8149 128.275C51.7895 127.913 51.7678 127.55 51.7499 127.187C51.7399 126.998 51.7299 126.81 51.7219 126.62L51.7019 126.124L51.6969 125.974L51.6809 125.517L51.6709 125.128C51.6709 124.973 51.6629 124.818 51.6609 124.663C51.6579 124.508 51.6539 124.338 51.6529 124.174C51.6509 124.01 51.6529 123.848 51.6479 123.685C51.6439 123.521 51.6479 123.358 51.6479 123.195C51.6479 81.3421 85.5789 47.4111 127.436 47.4111C169.292 47.4111 203.222 81.3411 203.222 123.195V124.174C203.222 124.337 203.217 124.501 203.214 124.663C203.214 124.798 203.208 124.931 203.204 125.068C203.204 125.188 203.199 125.309 203.195 125.425C203.195 125.578 203.186 125.731 203.181 125.884V125.896L203.16 126.427C203.153 126.582 203.147 126.738 203.139 126.893L203.134 127.003L203.107 127.499C203.048 128.562 202.967 129.623 202.866 130.683V130.696C202.849 130.87 202.832 131.044 202.813 131.218L202.768 131.629L202.679 132.433L202.628 132.84L202.565 133.319C202.542 133.493 202.519 133.668 202.493 133.841C202.467 134.036 202.438 134.23 202.409 134.424L202.34 134.883L202.258 135.403C202.23 135.576 202.2 135.748 202.168 135.92C202.135 136.093 202.109 136.265 202.079 136.437C202.019 136.781 201.956 137.125 201.89 137.468C201.789 137.981 201.686 138.493 201.58 139.005L201.47 139.512C201.434 139.681 201.395 139.851 201.357 140.02C199.224 137.947 196.399 136.818 193.284 136.818C190.457 136.818 187.55 137.753 184.641 139.598C182.711 140.824 180.578 142.996 178.381 145.726C176.346 142.904 173.498 141.029 170.242 140.516C169.621 140.418 168.993 140.368 168.364 140.368C160.925 140.368 156.45 146.821 154.757 152.626C153.917 154.587 149.887 163.519 143.825 169.577C134.596 178.775 132.268 188.254 136.766 198.407ZM215.007 177.998L214.977 178.087C214.901 178.288 214.813 178.484 214.714 178.674C214.639 178.814 214.558 178.95 214.47 179.082C214.303 179.331 214.12 179.569 213.921 179.793C213.875 179.845 213.831 179.897 213.779 179.948C213.707 180.025 213.634 180.101 213.559 180.175C212.213 181.509 210.161 182.679 207.841 183.752C207.578 183.871 207.311 183.99 207.042 184.11L206.774 184.229C206.595 184.308 206.416 184.386 206.228 184.463C206.049 184.541 205.863 184.619 205.677 184.695L205.119 184.925C203.814 185.462 202.477 185.974 201.173 186.479L200.615 186.696L200.064 186.912C199.697 187.055 199.335 187.198 198.979 187.341L198.448 187.555L197.926 187.768L197.67 187.876C197.499 187.947 197.332 188.018 197.165 188.089C193.328 189.736 190.567 191.411 191.147 193.489C191.163 193.548 191.181 193.604 191.201 193.659C191.253 193.813 191.324 193.958 191.413 194.095C191.465 194.176 191.525 194.253 191.592 194.323C192.274 195.032 193.515 194.92 195.08 194.357C195.3 194.276 195.519 194.192 195.736 194.104L195.872 194.048C196.23 193.896 196.609 193.726 196.996 193.542C197.093 193.496 197.191 193.452 197.289 193.401C199.203 192.465 201.372 191.205 203.524 190.058C204.385 189.593 205.258 189.152 206.142 188.733C208.18 187.774 210.096 187.094 211.636 187.094C212.359 187.094 212.997 187.242 213.529 187.582L213.618 187.641C213.952 187.876 214.232 188.178 214.441 188.528C214.482 188.595 214.522 188.666 214.561 188.739C215.322 190.184 214.685 191.68 213.194 193.147C211.763 194.556 209.537 195.937 207.007 197.215C206.819 197.31 206.631 197.405 206.44 197.498C198.91 201.196 189.049 203.981 188.912 204.016C186.284 204.697 182.526 205.591 178.292 206.26L177.666 206.358L177.563 206.373C177.089 206.445 176.614 206.512 176.138 206.574C175.655 206.639 175.167 206.698 174.676 206.753L174.586 206.763C172.806 206.968 171.019 207.104 169.228 207.169H169.202C168.554 207.192 167.907 207.204 167.259 207.204H166.512C165.524 207.191 164.538 207.146 163.553 207.07C163.53 207.07 163.505 207.07 163.482 207.064C163.129 207.037 162.777 207.004 162.425 206.965C162.06 206.926 161.696 206.882 161.333 206.833C161.094 206.801 160.856 206.765 160.618 206.726C160.376 206.687 160.134 206.647 159.893 206.605L159.564 206.543L159.539 206.538C159.192 206.472 158.847 206.399 158.503 206.319C158.303 206.274 158.104 206.23 157.907 206.176L157.788 206.146C157.69 206.122 157.595 206.096 157.498 206.07L157.445 206.056L157.137 205.966C157.025 205.935 156.913 205.901 156.801 205.868L156.762 205.857L156.471 205.768C156.361 205.734 156.251 205.698 156.142 205.662L155.874 205.573L155.677 205.504C155.487 205.437 155.298 205.368 155.111 205.296L154.933 205.226L154.786 205.168C154.502 205.054 154.22 204.935 153.941 204.81L153.756 204.72L153.725 204.706C153.659 204.675 153.594 204.644 153.528 204.617C153.399 204.555 153.271 204.491 153.144 204.426L153.105 204.407L152.921 204.31C152.594 204.139 152.274 203.957 151.96 203.764L151.788 203.658C151.702 203.605 151.616 203.55 151.532 203.494L151.308 203.346L151.067 203.18L150.923 203.077C150.771 202.969 150.622 202.857 150.476 202.742L150.243 202.563C150.15 202.488 150.058 202.412 149.967 202.335C149.89 202.272 149.815 202.206 149.74 202.14L149.734 202.135C149.653 202.064 149.574 201.993 149.495 201.92C149.417 201.849 149.339 201.777 149.263 201.704L149.254 201.695C149.174 201.619 149.096 201.542 149.019 201.463C148.942 201.385 148.863 201.307 148.788 201.227C148.713 201.148 148.636 201.067 148.562 200.984C148.488 200.902 148.42 200.827 148.35 200.746L148.327 200.719C148.259 200.641 148.192 200.562 148.126 200.481C147.983 200.31 147.844 200.135 147.71 199.956C147.575 199.776 147.443 199.592 147.314 199.405L147.191 199.221C147.027 198.981 146.867 198.739 146.712 198.493C146.596 198.316 146.483 198.138 146.373 197.957C146.302 197.844 146.234 197.73 146.166 197.618L146.138 197.572C146.073 197.462 146.009 197.354 145.947 197.245C145.911 197.186 145.877 197.127 145.845 197.066C145.812 197.004 145.774 196.941 145.739 196.878L145.682 196.779L145.647 196.715C145.58 196.595 145.514 196.474 145.45 196.352C145.42 196.298 145.391 196.244 145.36 196.192L145.271 196.019L145.181 195.848C144.956 195.398 144.743 194.942 144.543 194.48L144.472 194.311C144.426 194.198 144.383 194.086 144.337 193.975C144.315 193.921 144.293 193.868 144.274 193.814C144.167 193.537 144.067 193.257 143.975 192.975C143.942 192.874 143.91 192.775 143.88 192.675C143.808 192.448 143.743 192.219 143.685 191.988C143.614 191.719 143.551 191.448 143.498 191.175C143.487 191.12 143.476 191.065 143.467 191.012C143.415 190.745 143.373 190.476 143.34 190.206C143.332 190.153 143.326 190.1 143.32 190.047L143.303 189.885C143.281 189.673 143.264 189.46 143.254 189.247C143.254 189.193 143.249 189.139 143.247 189.087C143.242 188.981 143.24 188.875 143.239 188.769C143.183 184.496 145.345 180.388 149.968 175.767C158.203 167.54 162.997 155.501 162.997 155.501C162.997 155.501 163.126 154.996 163.394 154.269C163.431 154.168 163.47 154.064 163.514 153.955C163.67 153.548 163.846 153.148 164.041 152.758L164.08 152.683C164.246 152.351 164.428 152.027 164.624 151.712C164.67 151.639 164.714 151.567 164.765 151.494C164.912 151.277 165.067 151.065 165.23 150.86C165.319 150.749 165.416 150.639 165.513 150.532C165.552 150.49 165.59 150.448 165.631 150.408C166.108 149.915 166.653 149.513 167.27 149.299L167.348 149.273C167.4 149.256 167.452 149.24 167.505 149.225C167.566 149.209 167.627 149.195 167.69 149.182L167.719 149.176C167.849 149.15 167.981 149.133 168.114 149.124H168.125C168.194 149.124 168.264 149.117 168.335 149.117C168.424 149.117 168.507 149.117 168.594 149.126C168.684 149.134 168.773 149.144 168.863 149.158C169.605 149.276 170.311 149.718 170.919 150.4C171.15 150.66 171.358 150.94 171.54 151.236C171.66 151.428 171.773 151.631 171.88 151.845C171.923 151.934 171.964 152.016 172.004 152.104C172.108 152.33 172.202 152.56 172.284 152.795C172.479 153.345 172.626 153.911 172.723 154.487C172.807 154.992 172.857 155.502 172.873 156.013C172.881 156.286 172.881 156.563 172.873 156.842C172.819 158.14 172.553 159.421 172.086 160.634C172.044 160.745 171.997 160.857 171.952 160.969C171.86 161.195 171.759 161.417 171.65 161.634C171.569 161.799 171.484 161.965 171.392 162.13C171.332 162.24 171.269 162.35 171.206 162.46C171.045 162.734 170.871 163.006 170.684 163.277L170.571 163.439C170.129 164.055 169.637 164.633 169.099 165.167C168.569 165.698 168.001 166.189 167.4 166.637C166.798 167.083 166.233 167.577 165.711 168.114C164.208 169.691 163.858 171.083 164.196 172.138C164.25 172.304 164.321 172.465 164.407 172.617C164.508 172.791 164.628 172.951 164.764 173.097L164.817 173.152L164.871 173.206C164.925 173.258 164.982 173.309 165.043 173.359L165.103 173.407C165.248 173.519 165.402 173.619 165.563 173.707C165.61 173.732 165.652 173.757 165.705 173.781C165.879 173.866 166.058 173.939 166.242 173.998C166.293 174.015 166.344 174.03 166.396 174.046L166.461 174.063L166.551 174.087L166.628 174.106L166.712 174.124L166.795 174.141L166.874 174.154C166.932 174.164 166.992 174.174 167.052 174.181L167.109 174.19L167.213 174.2L167.277 174.207L167.382 174.214H167.444L167.554 174.22H167.9L167.999 174.214L168.113 174.207L168.252 174.194L168.382 174.179C168.412 174.179 168.442 174.171 168.472 174.165C168.872 174.107 169.264 174.001 169.639 173.849L169.798 173.782C169.887 173.743 169.977 173.702 170.059 173.658C170.235 173.57 170.406 173.47 170.57 173.361C170.799 173.211 171.015 173.043 171.217 172.858C171.265 172.815 171.312 172.769 171.358 172.725C171.381 172.703 171.403 172.682 171.425 172.658C171.469 172.613 171.514 172.569 171.558 172.52C171.878 172.168 172.155 171.78 172.383 171.363C174.34 167.804 176.391 164.298 178.534 160.849L178.828 160.378L179.125 159.907C179.273 159.668 179.423 159.433 179.572 159.199L179.722 158.965C180.22 158.185 180.726 157.41 181.241 156.641L181.546 156.185C182.158 155.278 182.768 154.396 183.373 153.558L183.674 153.143C184.332 152.236 185.017 151.348 185.728 150.482L186.01 150.144C186.057 150.088 186.1 150.032 186.151 149.978C186.244 149.868 186.337 149.761 186.428 149.657C186.474 149.604 186.517 149.552 186.566 149.5L186.834 149.198L186.968 149.051C187.103 148.906 187.235 148.767 187.365 148.634C187.455 148.544 187.538 148.455 187.624 148.371C188.131 147.853 188.69 147.388 189.293 146.985L189.433 146.895C189.567 146.805 189.706 146.721 189.848 146.645C192.212 145.303 194.169 145.204 195.296 146.331C195.978 147.013 196.356 148.144 196.335 149.718C196.335 149.787 196.335 149.857 196.33 149.929V150.006C196.33 150.078 196.324 150.15 196.318 150.223C196.318 150.313 196.308 150.402 196.299 150.492C196.29 150.581 196.285 150.649 196.276 150.729C196.276 150.751 196.272 150.774 196.268 150.798C196.262 150.867 196.253 150.938 196.243 151.009C196.243 151.03 196.243 151.052 196.235 151.074C196.224 151.169 196.21 151.263 196.194 151.357C196.183 151.447 196.168 151.531 196.152 151.619L196.126 151.768C196.1 151.91 196.067 152.05 196.026 152.188C195.948 152.447 195.854 152.7 195.743 152.946C195.588 153.284 195.417 153.613 195.229 153.933C195.125 154.111 195.018 154.286 194.907 154.459C194.793 154.638 194.673 154.819 194.549 155.002C194.233 155.454 193.905 155.897 193.564 156.33L193.408 156.527C192.852 157.22 192.278 157.899 191.686 158.562L191.499 158.772C191.247 159.053 190.991 159.336 190.729 159.62L190.532 159.834C190.401 159.977 190.264 160.12 190.132 160.264C190.001 160.407 189.864 160.552 189.726 160.697L189.315 161.13L188.898 161.566L188.478 162.002C188.196 162.294 187.913 162.586 187.628 162.878C183.573 167.037 179.301 171.182 177.855 173.766C177.758 173.934 177.671 174.108 177.593 174.285C177.387 174.755 177.301 175.157 177.36 175.482C177.379 175.589 177.416 175.691 177.471 175.785C177.552 175.926 177.651 176.056 177.766 176.172C177.819 176.224 177.875 176.272 177.934 176.316C178.232 176.528 178.591 176.637 178.957 176.627H179.071L179.188 176.618L179.305 176.605L179.402 176.591C179.415 176.589 179.429 176.587 179.442 176.583L179.531 176.566L179.554 176.561L179.653 176.54L179.688 176.531C179.723 176.522 179.757 176.513 179.792 176.503C179.827 176.493 179.875 176.48 179.917 176.466C180.093 176.413 180.265 176.35 180.434 176.278C180.523 176.242 180.61 176.203 180.696 176.161C180.741 176.141 180.786 176.12 180.828 176.098L180.962 176.032C181.282 175.866 181.594 175.685 181.898 175.491L182.031 175.401C182.076 175.373 182.121 175.344 182.164 175.312L182.297 175.223L182.368 175.174L182.56 175.039C182.739 174.916 182.906 174.789 183.075 174.66L183.09 174.648L183.359 174.44C183.726 174.15 184.074 173.858 184.39 173.583L184.6 173.399L184.619 173.381L184.729 173.284C184.987 173.052 185.217 172.836 185.408 172.658L185.487 172.581C185.556 172.516 185.619 172.455 185.676 172.403L185.788 172.292L185.828 172.253L185.839 172.242L185.956 172.125L186.03 172.048L186.039 172.041L186.074 172.009L186.118 171.969L186.132 171.956L186.169 171.922L186.373 171.743L186.487 171.641C186.548 171.588 186.607 171.534 186.666 171.479L186.802 171.358C186.827 171.338 186.851 171.316 186.876 171.294L187.019 171.169L187.229 170.984L187.341 170.887C187.776 170.509 188.305 170.052 188.913 169.537L189.162 169.326L189.573 168.981L189.994 168.63C190.544 168.173 191.136 167.688 191.762 167.185L192.173 166.855C192.523 166.576 192.882 166.292 193.246 166.006C193.393 165.891 193.542 165.776 193.694 165.662C194.066 165.373 194.44 165.086 194.817 164.803C195.675 164.155 196.56 163.506 197.456 162.874L197.84 162.606C198.109 162.421 198.377 162.235 198.645 162.054L198.888 161.89C199.367 161.565 199.853 161.248 200.343 160.939L200.586 160.786L200.827 160.636C201.069 160.486 201.309 160.339 201.548 160.196L201.787 160.053L202.265 159.775L202.734 159.506L202.829 159.454L203.2 159.25C203.355 159.166 203.509 159.085 203.663 159.006L203.892 158.888L204.115 158.776C204.193 158.739 204.27 158.7 204.346 158.663C204.848 158.415 205.36 158.187 205.88 157.979C206.021 157.919 206.161 157.865 206.3 157.818L206.71 157.674C206.833 157.633 206.953 157.594 207.068 157.559L207.108 157.547C207.17 157.527 207.232 157.509 207.293 157.493L207.311 157.488C207.439 157.451 207.566 157.419 207.691 157.389H207.7C208.054 157.304 208.414 157.243 208.777 157.206C208.944 157.189 209.111 157.18 209.279 157.181H209.363C209.475 157.181 209.583 157.188 209.69 157.199C209.739 157.199 209.788 157.209 209.836 157.215H209.856C209.904 157.221 209.952 157.228 210 157.239C210.047 157.248 210.095 157.256 210.141 157.267H210.156C210.203 157.277 210.245 157.289 210.294 157.303C210.548 157.374 210.79 157.484 211.012 157.628C211.121 157.699 211.223 157.779 211.317 157.868L211.344 157.894C211.362 157.91 211.379 157.927 211.395 157.944L211.444 157.997C211.846 158.418 212.178 158.901 212.428 159.427L212.466 159.517C212.551 159.717 212.618 159.924 212.666 160.135C212.808 160.781 212.753 161.455 212.508 162.07C212.415 162.318 212.302 162.557 212.169 162.785C211.858 163.309 211.489 163.796 211.07 164.237L210.981 164.332C210.848 164.472 210.71 164.612 210.565 164.752C210.501 164.815 210.434 164.877 210.367 164.94L210.162 165.129L210.055 165.224C209.797 165.454 209.532 165.677 209.263 165.893C209.1 166.025 208.936 166.154 208.77 166.281C208.184 166.729 207.587 167.161 206.979 167.578C206.612 167.83 206.242 168.077 205.869 168.321C204.95 168.924 204.021 169.512 203.083 170.084C201.115 171.294 198.934 172.588 196.609 173.995L196.007 174.36C195.348 174.762 194.726 175.146 194.14 175.512L193.845 175.697L193.287 176.055C192.917 176.292 192.548 176.531 192.179 176.77L191.882 176.966C191.737 177.06 191.593 177.156 191.449 177.252L191.308 177.342L190.876 177.633L190.647 177.79L190.379 177.976L190.13 178.149C189.713 178.444 189.325 178.725 188.968 178.992L188.834 179.094C188.624 179.253 188.416 179.415 188.211 179.58C187.902 179.829 187.62 180.067 187.367 180.296L187.243 180.409C187.172 180.474 187.102 180.539 187.035 180.603C186.989 180.648 186.946 180.693 186.898 180.736L186.834 180.8C186.691 180.944 186.551 181.091 186.416 181.242L186.35 181.318C186.203 181.488 186.075 181.651 185.963 181.81L185.913 181.881C185.825 182.009 185.744 182.141 185.671 182.277C185.652 182.311 185.635 182.345 185.618 182.379L185.569 182.481L185.536 182.555L185.515 182.605L185.498 182.65L185.475 182.711C185.413 182.88 185.37 183.056 185.345 183.234L185.337 183.296L185.331 183.354V183.669C185.331 183.695 185.331 183.721 185.338 183.749L185.343 183.797C185.343 183.823 185.349 183.848 185.353 183.876C185.357 183.902 185.364 183.949 185.372 183.986V183.991C185.379 184.026 185.386 184.06 185.395 184.095C185.404 184.13 185.413 184.17 185.424 184.206C185.443 184.277 185.467 184.347 185.492 184.417C185.508 184.459 185.523 184.5 185.54 184.541C185.54 184.549 185.546 184.558 185.55 184.566L185.586 184.647L185.636 184.758C185.69 184.873 185.749 184.985 185.813 185.094L185.879 185.208L185.947 185.322C185.959 185.341 185.973 185.359 185.988 185.376L186.01 185.399L186.035 185.422L186.061 185.442C186.099 185.469 186.14 185.49 186.183 185.505C186.206 185.513 186.23 185.519 186.254 185.525C186.831 185.655 188.017 185.178 189.593 184.346C189.682 184.298 189.78 184.248 189.875 184.196L190.355 183.934L190.589 183.804C190.756 183.715 190.926 183.614 191.1 183.515L191.417 183.336C193.5 182.137 195.988 180.597 198.56 179.093C198.801 178.952 199.043 178.811 199.285 178.672L199.771 178.361C200.335 178.038 200.902 177.719 201.471 177.404C202.188 177.01 202.91 176.626 203.639 176.254L204.115 176.013C204.431 175.857 204.744 175.705 205.053 175.557C205.651 175.273 206.256 175.003 206.868 174.748L207.203 174.612L207.243 174.596C209.018 173.893 210.627 173.459 211.929 173.459C212.21 173.456 212.492 173.48 212.769 173.528H212.778C212.867 173.544 212.948 173.562 213.031 173.582H213.046C213.259 173.636 213.466 173.713 213.662 173.812C213.937 173.954 214.184 174.143 214.393 174.371C214.489 174.477 214.574 174.592 214.649 174.714C214.789 174.929 214.899 175.162 214.978 175.406C215.01 175.501 215.038 175.594 215.067 175.693C215.278 176.45 215.257 177.253 215.007 177.998Z" fill="#FF9D00"/>
      <path fill-rule="evenodd" clip-rule="evenodd" d="M203.21 123.685V123.194C203.21 81.34 169.292 47.411 127.435 47.411C85.5791 47.411 51.648 81.342 51.648 123.194V123.358C51.646 123.467 51.645 123.576 51.648 123.685C51.6529 123.848 51.6546 124.011 51.653 124.174L51.6581 124.534L51.661 124.663C51.661 124.723 51.6631 124.782 51.6651 124.842C51.6681 124.937 51.67 125.033 51.67 125.128L51.681 125.517L51.697 125.974L51.702 126.124L51.722 126.597V126.62C51.73 126.805 51.7401 126.989 51.7491 127.173L51.75 127.187C51.76 127.375 51.7701 127.564 51.7821 127.753C51.7921 127.927 51.802 128.101 51.815 128.275L51.8171 128.306C51.8258 128.455 51.8358 128.605 51.847 128.754L51.85 128.794L51.883 129.226L51.8861 129.254C51.8921 129.338 51.898 129.422 51.906 129.503C51.9658 130.224 52.0355 130.945 52.1151 131.664L52.12 131.709L52.181 132.238L52.2491 132.793L52.299 133.17L52.322 133.347C52.3753 133.755 52.433 134.162 52.495 134.568L52.4991 134.595L52.558 134.979C52.8435 136.808 53.1971 138.626 53.618 140.429L53.6231 140.451L53.655 140.586L53.746 140.971L53.802 140.904C56.002 138.274 59.158 136.824 62.689 136.824C65.519 136.824 68.4221 137.76 71.3321 139.605C73.2621 140.831 75.3961 143.002 77.5921 145.733C79.6241 142.911 82.4721 141.035 85.7301 140.523C86.3513 140.425 86.9792 140.376 87.6081 140.375C95.0441 140.375 99.523 146.828 101.215 152.633C102.051 154.594 106.08 163.526 112.156 169.568C121.392 178.795 123.703 188.316 119.132 198.511H119.148C119.459 198.546 119.772 198.578 120.087 198.607C120.274 198.625 120.46 198.643 120.648 198.659L120.714 198.665L121.127 198.7L121.507 198.73C121.869 198.758 122.232 198.784 122.596 198.807L122.885 198.824L123.114 198.838L123.256 198.846L123.703 198.869L123.825 198.874L124.294 198.895L124.816 198.915L125.235 198.927L125.305 198.929C125.394 198.933 125.483 198.936 125.572 198.936L125.668 198.939C126.258 198.953 126.847 198.96 127.437 198.959H128.063L128.51 198.954C128.62 198.949 128.729 198.949 128.84 198.949H129.014L129.165 198.945C129.224 198.943 129.283 198.941 129.343 198.941H129.522L129.873 198.932L130.401 198.914L130.982 198.888C131.15 198.882 131.316 198.873 131.482 198.865L131.661 198.854L131.927 198.84L132.083 198.831L132.201 198.823L132.738 198.788L133.274 198.749L133.761 198.71L134.103 198.681L134.479 198.647C135.107 198.591 135.733 198.525 136.359 198.45L136.786 198.399C132.287 188.247 134.616 178.767 143.813 169.577C149.876 163.519 153.905 154.587 154.745 152.625C156.438 146.821 160.914 140.368 168.352 140.368C168.981 140.368 169.61 140.418 170.231 140.516C173.486 141.028 176.334 142.904 178.369 145.726C180.566 142.996 182.699 140.823 184.63 139.597C187.539 137.753 190.445 136.817 193.272 136.817C196.388 136.817 199.212 137.947 201.345 140.02C201.384 139.851 201.422 139.682 201.459 139.512L201.568 139.006C201.607 138.821 201.646 138.636 201.683 138.451C201.749 138.124 201.815 137.797 201.878 137.467C201.944 137.125 202.007 136.781 202.067 136.437L202.098 136.251C202.117 136.141 202.135 136.031 202.156 135.92C202.19 135.748 202.218 135.576 202.246 135.402L202.257 135.336L202.328 134.883L202.398 134.424V134.42C202.449 134.081 202.497 133.742 202.542 133.403L202.553 133.319L202.616 132.841L202.667 132.433L202.757 131.629L202.792 131.306L202.801 131.218C202.82 131.044 202.838 130.87 202.854 130.696V130.682C202.867 130.544 202.881 130.405 202.893 130.266C202.964 129.478 203.024 128.686 203.072 127.891C203.081 127.761 203.088 127.63 203.096 127.499V127.493L203.122 127.002L203.128 126.892C203.144 126.56 203.158 126.228 203.169 125.896V125.884L203.174 125.754C203.179 125.645 203.183 125.535 203.183 125.425L203.185 125.381C203.189 125.278 203.193 125.172 203.193 125.067L203.196 124.977C203.199 124.872 203.202 124.768 203.202 124.663L203.204 124.574C203.207 124.441 203.21 124.307 203.21 124.174V123.685ZM108.638 199.391C114.64 190.59 114.214 183.984 105.98 175.754C97.7441 167.523 92.951 155.487 92.951 155.487C92.951 155.487 91.1621 148.496 87.0821 149.138C83.0021 149.78 80.0091 160.227 88.5521 166.622C97.0941 173.017 86.8521 177.353 83.5641 171.352C80.2761 165.35 71.299 149.923 66.645 146.972C61.991 144.021 58.718 145.675 59.815 151.757C60.36 154.776 65.4281 159.929 70.1631 164.743C74.9671 169.627 79.428 174.163 78.474 175.768C76.581 178.955 69.9141 172.023 69.9141 172.023C69.9141 172.023 49.038 153.025 44.494 157.976C40.304 162.539 46.765 166.418 56.7211 172.397C57.5671 172.905 58.4391 173.429 59.3321 173.969C70.7231 180.865 71.609 182.684 69.992 185.293C69.395 186.257 65.582 183.968 60.892 181.153C52.897 176.352 42.3551 170.023 40.8661 175.688C39.5781 180.591 47.334 183.595 54.368 186.32C60.228 188.59 65.5881 190.666 64.7991 193.484C63.9821 196.406 59.5531 193.969 54.7121 191.305C49.2771 188.314 43.3221 185.038 41.3731 188.735C37.6901 195.725 66.7831 203.954 67.0231 204.015C76.4231 206.453 100.295 211.619 108.638 199.391ZM147.303 199.391C141.301 190.59 141.727 183.984 149.962 175.754C158.197 167.523 162.99 155.487 162.99 155.487C162.99 155.487 164.779 148.496 168.859 149.138C172.939 149.78 175.932 160.227 167.39 166.622C158.847 173.017 169.089 177.353 172.377 171.352C175.666 165.35 184.637 149.923 189.291 146.972C193.945 144.021 197.22 145.675 196.122 151.757C195.578 154.776 190.509 159.929 185.774 164.744C180.97 169.628 176.509 174.163 177.462 175.768C179.355 178.955 186.027 172.019 186.027 172.019C186.027 172.019 206.902 153.022 211.448 157.973C215.637 162.535 209.176 166.415 199.219 172.394C198.348 172.917 197.478 173.441 196.609 173.966C185.218 180.862 184.332 182.681 185.948 185.289C186.546 186.254 190.359 183.964 195.048 181.149C203.044 176.349 213.586 170.019 215.075 175.685C216.364 180.588 208.607 183.592 201.573 186.317C195.713 188.587 190.353 190.663 191.141 193.481C191.957 196.402 196.385 193.965 201.225 191.301C206.66 188.31 212.616 185.032 214.564 188.732C218.248 195.726 189.15 203.947 188.915 204.007C179.515 206.453 155.643 211.619 147.303 199.391Z" fill="#FFD21E"/>
      <path fill-rule="evenodd" clip-rule="evenodd" d="M152.047 102.567C153.229 102.985 154.108 104.257 154.944 105.468C156.074 107.104 157.126 108.627 158.74 107.769C160.644 106.756 162.205 105.202 163.225 103.302C164.246 101.402 164.681 99.2427 164.475 97.096C164.321 95.4908 163.813 93.9398 162.987 92.5548C162.161 91.1697 161.038 89.985 159.7 89.0862C158.361 88.1874 156.839 87.5968 155.245 87.3569C153.65 87.117 152.022 87.2339 150.478 87.699C148.934 88.1639 147.513 88.9653 146.316 90.0455C145.119 91.1257 144.176 92.4578 143.556 93.946C142.936 95.4342 142.653 97.0415 142.728 98.652C142.804 100.263 143.235 101.836 143.992 103.26C144.74 104.667 146.4 104.003 148.152 103.302C149.525 102.753 150.956 102.181 152.047 102.567ZM100.672 102.567C99.49 102.985 98.611 104.258 97.775 105.468C96.645 107.105 95.592 108.627 93.979 107.769C91.5845 106.501 89.7482 104.386 88.8278 101.838C87.9075 99.2895 87.9692 96.4896 89.0008 93.9841C90.0324 91.4786 91.9601 89.4471 94.408 88.2855C96.856 87.1239 99.6488 86.9156 102.242 87.701C104.307 88.3228 106.141 89.5427 107.513 91.2065C108.885 92.8704 109.732 94.9035 109.949 97.049C110.165 99.1945 109.74 101.356 108.728 103.26C107.979 104.667 106.319 104.003 104.567 103.303C103.193 102.753 101.764 102.181 100.672 102.567ZM144.099 149.318C152.242 142.903 155.233 132.429 155.233 125.977C155.233 120.877 151.802 122.482 146.309 125.202L145.999 125.355C140.957 127.852 134.245 131.177 126.877 131.177C119.508 131.177 112.796 127.852 107.755 125.354C102.084 122.545 98.527 120.783 98.527 125.978C98.527 132.634 101.709 143.563 110.443 149.912C111.596 147.573 113.219 145.497 115.211 143.813C117.202 142.129 119.52 140.874 122.018 140.126C122.89 139.866 123.788 141.367 124.707 142.904C125.594 144.386 126.501 145.902 127.423 145.902C128.406 145.902 129.371 144.408 130.314 142.95C131.299 141.425 132.26 139.94 133.189 140.237C137.864 141.738 141.775 144.993 144.099 149.318Z" fill="#32343D"/>
      <path d="M144.097 149.317C139.856 152.659 134.219 154.9 126.878 154.9C119.981 154.9 114.587 152.922 110.443 149.911C111.596 147.572 113.219 145.495 115.211 143.812C117.202 142.128 119.52 140.873 122.018 140.125C123.73 139.614 125.545 145.901 127.423 145.901C129.433 145.901 131.37 139.655 133.189 140.236C137.863 141.738 141.773 144.993 144.097 149.317Z" fill="#FF323D"/>
      <path fill-rule="evenodd" clip-rule="evenodd" d="M81.2 111.64C80.2312 112.288 79.1173 112.687 77.9572 112.801C76.7971 112.916 75.6267 112.742 74.55 112.295C73.6893 111.94 72.9072 111.418 72.2488 110.759C71.5903 110.101 71.0684 109.319 70.713 108.458C70.267 107.381 70.0935 106.211 70.2082 105.051C70.3228 103.891 70.7219 102.777 71.37 101.808C72.1488 100.642 73.2558 99.7333 74.5512 99.1967C75.8466 98.6601 77.272 98.5197 78.6471 98.7935C80.0223 99.0672 81.2853 99.7427 82.2764 100.734C83.2675 101.726 83.9422 102.99 84.215 104.365C84.4883 105.74 84.3477 107.165 83.8113 108.46C83.2748 109.755 82.3654 110.861 81.2 111.64ZM182.613 111.64C181.644 112.288 180.53 112.687 179.37 112.801C178.209 112.916 177.039 112.742 175.962 112.295C175.101 111.939 174.319 111.418 173.661 110.759C173.003 110.101 172.481 109.319 172.125 108.458C171.68 107.381 171.507 106.211 171.621 105.051C171.736 103.891 172.135 102.777 172.782 101.808C173.364 100.936 174.133 100.205 175.032 99.6658C175.931 99.1269 176.938 98.7942 177.981 98.6917C179.025 98.5891 180.078 98.7193 181.064 99.0728C182.051 99.4264 182.947 99.9944 183.688 100.736C184.68 101.727 185.355 102.99 185.628 104.365C185.902 105.74 185.761 107.165 185.224 108.46C184.687 109.755 183.779 110.861 182.613 111.64Z" fill="#FFAD03"/>
    </svg>
    `

    const isGallery = window.location.href.endsWith("ray-overview/examples.html")
    if (isGallery) {
        const tags = {
          useCaseTags: [
            {
              className: 'llm',
              displayName: 'Large Language Models',
              icon: llmIcon
            },
            {
              className: 'cv',
              displayName: 'Computer Vision',
              icon: computerVisionIcon,
            },
            {
              className: 'ts',
              displayName: 'Time-series',
              icon: timeSeriesIcon,
            },
            {
              className: 'nlp',
              displayName: 'Natural Language Processing',
              icon: nlpIcon,
            },
            {
              className: 'rl',
              displayName: 'Reinforcement Learning',
              icon: rlIcon,
            },
          ],
          workloadTags: [
            {
              className: 'data-processing',
              displayName: 'Data Processing',
              icon: dataPreprocessingIcon,
            },
            {
              className: 'training',
              displayName: 'Model Training & Fine-tuning',
              icon: modelTrainingIcon,
            },
            {
              className: 'tuning',
              displayName: 'Hyperparameter Tuning',
              icon: hyperparameterTuningIcon,
            },
            {
              className: 'inference',
              displayName: 'Batch Inference',
              icon: batchInferenceIcon,
            },
            {
              className: 'serving',
              displayName: 'Model Serving',
              icon: servingIcon,
            },
          ],
          mlopsTags: [
            {
              className: 'tracking',
              displayName: 'Experiment Tracking',
              icon: experimentTrackingIcon,
            },
            {
              className: 'monitoring',
              displayName: 'Monitoring',
              icon: monitoringIcon,
            },
          ],
          frameworkTags: [
            {
              className: 'pytorch',
              displayName: 'PyTorch',
              icon: pytorchIcon,
            },
            {
              className: 'huggingface',
              displayName: 'HuggingFace',
              icon: huggingfaceIcon,
            },
            {
              className: 'tensorflow',
              displayName: 'Tensorflow/Keras',
              icon: tensorflowIcon,
            },
          ]
        }

        const useCaseTags = tags.useCaseTags.map(({className, displayName, icon}) => {
          return generateTagButton(className, displayName, icon)
        })
        const workloadTags = tags.workloadTags.map(({className, displayName, icon}) => {
          return generateTagButton(className, displayName, icon)
        })
        const mlopsTags = tags.mlopsTags.map(({className, displayName, icon}) => {
          return generateTagButton(className, displayName, icon)
        })
        const frameworkTags = tags.frameworkTags.map(({className, displayName, icon}) => {
          return generateTagButton(className, displayName, icon)
        })


        const tagString = "<div>\n" +
            "<h5>Filter by</h5><hr>\n" +
            generateTagSection("USE CASES", useCaseTags) +
            generateTagSection("ML WORKLOADS", workloadTags) +
            generateTagSection("MLOPS", mlopsTags) +
            generateTagSection("FRAMEWORKS", frameworkTags) +
            "</div>";

        const tempDiv = document.createElement('div');
        tempDiv.innerHTML = tagString;
        const newNav = tempDiv.firstChild;

        // Populate the sidebar with buttons that filter for different example tags
        document.getElementById("site-navigation").appendChild(newNav);

        document.querySelectorAll('.tag').forEach(tag => {
            tag.addEventListener('click', generateTagClickHandler(tag, tags));
        });

        const searchInput = document.getElementById("searchInput");
        if (searchInput) {
            searchInput.addEventListener("keyup", function (event) {
                event.preventDefault();
                filterPanels(tags);
            });
        }
    }
});
